from setuptools import setup

setup(name='liuguangrui',
      version='0.1',
      description='test1',
      author='liuguangrui',
      author_email='18302465887@163.com',
      packages=['lgr'],
      zip_safe=False)
